{% extends "base.html" %}
{% block title %}Arduinozore{% end %}
{% block subtitle %}<a class="item" href="/">Accueil</a><div class="active item">Paramètres</div>{% end %}
{% block head %}
{% end %}
{% block body %}
<h1>Paramètres</h1>
<div class="ui middle aligned animated list">
    {% for a_s in available_settings%}
    <a class="item" href="/{{available_settings[a_s]}}">
        <i class="settings icon"></i>
        <div class="content">
            <div class="header">{{a_s}}</div>
            <div class="description">Configuration</div>
        </div>
    </a>
    {% end %}
</div>
{% end %}
