{% extends "../base.html" %}
{% block title %}Arduinozore{% end %}
{% block subtitle %}
<a class="item" href="/">Accueil</a>
<a class="item" href="/settings">Paramètres</a>
{% block submenu%}
<div class="active item">Devices</div>
{% end %}
{% end %}
